@@ -18,7 +18,11 @@
 #ifndef M_PI
 #define M_PI           3.14159265358979323846  /* pi */
 #endif
+#if TARGET_RT_MAC_MACHO
+#define DIR_DELIM '/'
+#else
 #define DIR_DELIM ':'
+#endif
 #define myWaitAndProcessNextEvent Nlm_ProcessAnEvent
 extern int Nlm_textScrapFull;
 
@@ -152,12 +156,13 @@ void prepare_fonts(void);
 void change_panel_size(Nlm_PaneL panel, int change_x, int change_y);
 void err_message(char *text);
 void place_midpoint_root(void);
-char *extract_filename( const char *fname);
+char *extract_filename(char *fname);
 void save_plot_callback(Nlm_IteM ob);
 void font_callback(Nlm_ChoicE choix);
 void paper_callback(Nlm_ChoicE ob);
 void exit_callback(Nlm_IteM ob);
 void tree_draw_proc(Nlm_PaneL panel);
+void set_tree_w_title(Nlm_WindoW w, char *file, int tips);
 void init_tree(char *titre);
 void debut_arbre(void);
 void my_draw_line(int dx, int dy, int fx, int fy, int col, int ps, int h);
@@ -189,6 +194,7 @@ void print_plot(Nlm_IteM);
 #ifdef WIN_MAC
 int crefpict(char *, PicHandle );
 extern void add_apropos(char *);
+extern char *mac_fname_to_roman(char *);
 #else
 void process_args(int *argc, char *argv[]);
 void remove_arg(int target, int *argc, char *argv[]);
@@ -309,7 +315,7 @@ else    {
    fd_unrooted->tree_name = fname;
    /* show the first form */
    if(*fname != 0) debut_arbre();
-   Nlm_SetTitle(fd_unrooted->unrooted, (*fname == 0 ? "unrooted" : fname) );
+   set_tree_w_title(fd_unrooted->unrooted, (*fname == 0 ? "unrooted" : fname), notu );
    Nlm_Show(fd_unrooted->unrooted);
    p_rect = (Nlm_RecT *)Nlm_GetWindowExtra(fd_unrooted->unrooted);
    Nlm_ObjectRect(fd_unrooted->unrooted, p_rect);
@@ -435,9 +441,9 @@ place_menu = win;
 
   Nlm_Break(win);
 
-#ifdef LESSTIF 
+#ifdef WIN_MOTIF 
 /* bug in LessTif : resize does not work if nothing except panel */
-{ Nlm_Handle obj;
+{ Nlm_Handle obj; Nlm_PoinT position;
 Nlm_GetNextPosition(win, &position);
 obj = Nlm_PushButton(win,"void",NULL); Nlm_Hide(obj);
 Nlm_SetNextPosition(win, position);
@@ -487,21 +493,26 @@ void change_panel_size(Nlm_PaneL panel, int change_x, int change_y)
 Nlm_RecT r, r_group;
 Nlm_GrouP group;
 Nlm_Boolean in_group;
+static int recursive = FALSE;
 
 
+Nlm_GetPosition(panel, &r);
+#ifdef WIN_MOTIF
+if(recursive) return;
+recursive = TRUE;
 group = Nlm_Parent(panel);
 in_group = (group != Nlm_ParentWindow(panel));
-Nlm_GetPosition(panel, &r);
 if(in_group) {
         Nlm_GetPosition(group, &r_group);
         Nlm_Hide(group);
         }
 else
         Nlm_Hide(panel);
-Nlm_Reset(panel);
+#endif
 r.bottom += change_y;
 r.right += change_x;
 Nlm_SetPosition(panel, &r);
+#ifdef WIN_MOTIF
 if(in_group) {
         r_group.bottom += change_y;
         r_group.right += change_x;
@@ -509,6 +520,8 @@ if(in_group) {
         Nlm_Show(group);
         }
 else    Nlm_Show(panel);
+recursive = FALSE;
+#endif
 }
 
 
@@ -631,6 +644,7 @@ for(num = 1; num < *argc; num++) {
 void open_callback(Nlm_IteM ob)
 {
 Nlm_Boolean reponse;
+char *p;
 
 reponse = MG_GetInputFName(fname, sizeof(fname) );
 if(!reponse) {
@@ -642,12 +656,23 @@ if(notu != 0) free_tree();
 notu = 0;
 debut_arbre();
 plot_aux_data.comp_phys_bounds = TRUE;
-Nlm_SetTitle(fd_unrooted->unrooted, 
-                (notu == 0 ? "unrooted" : extract_filename(fname) ) );
+set_tree_w_title(fd_unrooted->unrooted, fname, notu);
 tree_draw_proc(fd_unrooted->tree_plot);
 }
 
 
+void set_tree_w_title(Nlm_WindoW w, char *file, int tips)
+{
+char tmp[200];
+
+file = extract_filename(file);
+#ifdef WIN_MAC
+file = mac_fname_to_roman(file);
+#endif
+if(tips != 0) sprintf(tmp, "%s (%d tips)", file, tips + 1);
+Nlm_SetTitle(w, (tips == 0 ? "unrooted" : tmp ) );
+}
+
 
 void paper_callback(Nlm_ChoicE ob)
 {
@@ -760,13 +785,11 @@ Nlm_Remove(alwin);
 
 
 
-char *extract_filename( const char *fname)
+char *extract_filename(char *name)
 {
-char *p, *q;
-        q = (char *)fname;
-        do      { p=strchr(q,DIR_DELIM); if(p != NULL) q = p+1; }
-        while   (p!=NULL);
-return q;
+char *p;
+while( ( p = strchr(name, DIR_DELIM) ) != NULL) name = p + 1;
+return name;
 }
 
 
@@ -886,7 +909,7 @@ strcpy(fname, tmpfname);
 debut_arbre();
 remove(tmpfname);
 if(notu > 0) {
-	Nlm_SetTitle(fd_unrooted->unrooted, pasted_title);
+	set_tree_w_title(fd_unrooted->unrooted, pasted_title, notu);
 	strcpy(fname, pasted_title);
 	plot_aux_data.comp_phys_bounds = TRUE;
 	tree_draw_proc(fd_unrooted->tree_plot);
@@ -1015,7 +1038,7 @@ if( !doing_copy ) tree_draw_proc(fd_unrooted->tree_plot);
 void init_tree(char *titre)
 {
 debut_arbre();
-Nlm_SetTitle(fd_unrooted->unrooted, titre );
+set_tree_w_title(fd_unrooted->unrooted, titre, notu);
 tree_draw_proc(fd_unrooted->tree_plot);
 }
 
@@ -1036,6 +1059,7 @@ if( (pname=preptree(fname)) != NULL ) {
         strcpy(mess, pname); strcat(mess, fname);
         err_message(mess);
         notu = 0;
+		Nlm_UseWindow(fd_unrooted->unrooted);
         return;
         }
 bigracine = cre_new_tree(racine, NULL, NULL);
@@ -1511,6 +1535,9 @@ time_t heure;
 int h, ascent, descent;
 
 time (&heure);
+#ifdef WIN_MAC
+text = mac_fname_to_roman(text);
+#endif
 sprintf(ligne, "unrooted    %s    %s", text, ctime(&heure) );
 h = strlen(ligne); ligne[h - 1] = 0;
 h = my_get_char_height(&ascent, &descent);
